DebugRequest

Enum DebugRequest 

pub enum DebugRequest {
    Compact {
        responder: DebugCompactResponder,
    },
    DeleteProfile {
        volume: String,
        profile: String,
        responder: DebugDeleteProfileResponder,
    },
    RecordAndReplayProfile {
        volume: Option<String>,
        profile: String,
        duration_secs: u32,
        responder: DebugRecordAndReplayProfileResponder,
    },
    ReplayXorRecordProfile {
        volume: String,
        profile: String,
        duration_secs: u32,
        responder: DebugReplayXorRecordProfileResponder,
    },
    StopProfileTasks {
        responder: DebugStopProfileTasksResponder,
    },
}
This is an internal protocol for on-device debugging and testing only. See ffx fxfs help for more details.

Variants



Compact

Forces a compaction.

Fields



DeleteProfile

Deletes a recorded profile from a volume. Fails if the volume isn’t mounted or there is active profile recording or replay.

Fields

volume: String
profile: String


RecordAndReplayProfile

Begins recording a profile for a named volume for up to the given duration in seconds. If a profile already exists under the given name then it will begin replaying it as well. Fails if the volume isn’t mounted or there is active profile recording or replay on the volume. Page faults for objects that do not get opened by a caller during the recording period will will be filtered out of the profile.

This “record-while-replaying” strategy is meant to support boot-profiling in an environment where we don’t explicitly know when the system has updated. By recording during replay and filtering objects without open events, Fxfs drops dead/replaced objects to refresh the profile.

Fields

volume: Option<String>
profile: String
duration_secs: u32


ReplayXorRecordProfile

Replays a profile if one exists, and only records if one does not exist. Fails if the volume isn’t mounted or there is active profile recording or replay on the volume.

This profile method is meant to support app launch profiling. These profiles do not filter entries based on Open events since outside of the boot process objects may already be opened or cached in overlays like Starnix.

Fields

volume: String
profile: String
duration_secs: u32


StopProfileTasks

Stops all profile recording and replay activity. Ongoing recordings are completed and persisted.

Implementations