pub struct CryptCreateKeyWithIdResponse {
pub wrapped_key: WrappedKey,
pub unwrapped_key: Vec<u8>,
pub key_token: Option<EventPair>,
}Fields
wrapped_key: WrappedKeyunwrapped_key: Vec<u8>key_token: Option<EventPair>Trait Implementations
Sourceimpl Debug for CryptCreateKeyWithIdResponse
impl Debug for CryptCreateKeyWithIdResponse
Sourceimpl Decode<CryptCreateKeyWithIdResponse, DefaultFuchsiaResourceDialect> for CryptCreateKeyWithIdResponse
impl Decode<CryptCreateKeyWithIdResponse, DefaultFuchsiaResourceDialect> for CryptCreateKeyWithIdResponse
Sourceimpl Encode<CryptCreateKeyWithIdResponse, DefaultFuchsiaResourceDialect> for &mut CryptCreateKeyWithIdResponse
impl Encode<CryptCreateKeyWithIdResponse, DefaultFuchsiaResourceDialect> for &mut CryptCreateKeyWithIdResponse
Sourceimpl<T0: Encode<WrappedKey, DefaultFuchsiaResourceDialect>, T1: Encode<Vector<u8, 80>, DefaultFuchsiaResourceDialect>, T2: Encode<Optional<HandleType<EventPair, { _ }, 2147483648>>, DefaultFuchsiaResourceDialect>> Encode<CryptCreateKeyWithIdResponse, DefaultFuchsiaResourceDialect> for (T0, T1, T2)
impl<T0: Encode<WrappedKey, DefaultFuchsiaResourceDialect>, T1: Encode<Vector<u8, 80>, DefaultFuchsiaResourceDialect>, T2: Encode<Optional<HandleType<EventPair, { _ }, 2147483648>>, DefaultFuchsiaResourceDialect>> Encode<CryptCreateKeyWithIdResponse, DefaultFuchsiaResourceDialect> for (T0, T1, T2)
Sourceimpl ResourceTypeMarker for CryptCreateKeyWithIdResponse
impl ResourceTypeMarker for CryptCreateKeyWithIdResponse
Sourcetype Borrowed<'a> = &'a mut CryptCreateKeyWithIdResponse
type Borrowed<'a> = &'a mut CryptCreateKeyWithIdResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).impl Standalone<DefaultFuchsiaResourceDialect> for CryptCreateKeyWithIdResponse
impl StructuralPartialEq for CryptCreateKeyWithIdResponse
Sourceimpl TypeMarker for CryptCreateKeyWithIdResponse
impl TypeMarker for CryptCreateKeyWithIdResponse
Sourcetype Owned = CryptCreateKeyWithIdResponse
type Owned = CryptCreateKeyWithIdResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Auto Trait Implementations
impl Freeze for CryptCreateKeyWithIdResponse
impl RefUnwindSafe for CryptCreateKeyWithIdResponse
impl Send for CryptCreateKeyWithIdResponse
impl Sync for CryptCreateKeyWithIdResponse
impl Unpin for CryptCreateKeyWithIdResponse
impl UnsafeUnpin for CryptCreateKeyWithIdResponse
impl UnwindSafe for CryptCreateKeyWithIdResponse