pub struct DebugReplayXorRecordProfileRequest {
pub volume: String,
pub profile: String,
pub duration_secs: u32,
}Fields
volume: Stringprofile: Stringduration_secs: u32Trait Implementations
Sourceimpl Clone for DebugReplayXorRecordProfileRequest
impl Clone for DebugReplayXorRecordProfileRequest
Sourcefn clone(&self) -> DebugReplayXorRecordProfileRequest
fn clone(&self) -> DebugReplayXorRecordProfileRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D> Decode<DebugReplayXorRecordProfileRequest, D> for DebugReplayXorRecordProfileRequestwhere
D: ResourceDialect,
impl<D> Decode<DebugReplayXorRecordProfileRequest, D> for DebugReplayXorRecordProfileRequestwhere
D: ResourceDialect,
Sourcefn new_empty() -> DebugReplayXorRecordProfileRequest
fn new_empty() -> DebugReplayXorRecordProfileRequest
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<DebugReplayXorRecordProfileRequest, D> for &DebugReplayXorRecordProfileRequestwhere
D: ResourceDialect,
impl<D> Encode<DebugReplayXorRecordProfileRequest, D> for &DebugReplayXorRecordProfileRequestwhere
D: ResourceDialect,
Sourceimpl Ord for DebugReplayXorRecordProfileRequest
impl Ord for DebugReplayXorRecordProfileRequest
Sourcefn cmp(&self, other: &DebugReplayXorRecordProfileRequest) -> Ordering
fn cmp(&self, other: &DebugReplayXorRecordProfileRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DebugReplayXorRecordProfileRequest
impl PartialEq for DebugReplayXorRecordProfileRequest
Sourcefn eq(&self, other: &DebugReplayXorRecordProfileRequest) -> bool
fn eq(&self, other: &DebugReplayXorRecordProfileRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DebugReplayXorRecordProfileRequest
impl PartialOrd for DebugReplayXorRecordProfileRequest
Sourceimpl TypeMarker for DebugReplayXorRecordProfileRequest
impl TypeMarker for DebugReplayXorRecordProfileRequest
Sourcetype Owned = DebugReplayXorRecordProfileRequest
type Owned = DebugReplayXorRecordProfileRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for DebugReplayXorRecordProfileRequest
impl ValueTypeMarker for DebugReplayXorRecordProfileRequest
Sourcetype Borrowed<'a> = &'a DebugReplayXorRecordProfileRequest
type Borrowed<'a> = &'a DebugReplayXorRecordProfileRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<DebugReplayXorRecordProfileRequest as TypeMarker>::Owned,
) -> <DebugReplayXorRecordProfileRequest as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<DebugReplayXorRecordProfileRequest as TypeMarker>::Owned, ) -> <DebugReplayXorRecordProfileRequest as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.impl Eq for DebugReplayXorRecordProfileRequest
impl Persistable for DebugReplayXorRecordProfileRequest
impl StructuralPartialEq for DebugReplayXorRecordProfileRequest