DebugRequest

Enum DebugRequest 

pub enum DebugRequest {
    Compact {
        responder: DebugCompactResponder,
    },
    DeleteProfile {
        volume: String,
        profile: String,
        responder: DebugDeleteProfileResponder,
    },
    RecordReplayProfile {
        volume: Option<String>,
        profile: String,
        duration_secs: u32,
        responder: DebugRecordReplayProfileResponder,
    },
    StopProfileTasks {
        responder: DebugStopProfileTasksResponder,
    },
}
This is an internal protocol for on-device debugging and testing only. See ffx fxfs help for more details.

Variants



Compact

Forces a compaction.

Fields



DeleteProfile

Deletes a recorded profile from a volume. Fails if the volume isn’t mounted or there is active profile recording or replay.

Fields

volume: String
profile: String


RecordReplayProfile

Begins recording a profile for a named volume for up to the given duration in seconds. If a profile already exists under the given name then it will begin replaying it as well. Fails if the volume isn’t mounted or there is active profile recording or replay on the volume.

Fields

volume: Option<String>
profile: String
duration_secs: u32


StopProfileTasks

Stops all profile recording and replay activity. Ongoing recordings are completed and persisted.

Implementations